( cd opt/kde/share/doc/HTML/xh/amor ; rm -rf common )
( cd opt/kde/share/doc/HTML/xh/amor ; ln -sf /opt/kde/share/doc/HTML/xh/common common )
( cd opt/kde/share/doc/HTML/xh/kmail ; rm -rf common )
( cd opt/kde/share/doc/HTML/xh/kmail ; ln -sf /opt/kde/share/doc/HTML/xh/common common )
( cd opt/kde/share/doc/HTML/xh/khelpcenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/xh/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/xh/common common )
( cd opt/kde/share/doc/HTML/xh/kmenuedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/xh/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/xh/common common )
( cd opt/kde/share/doc/HTML/xh/kioslave ; rm -rf common )
( cd opt/kde/share/doc/HTML/xh/kioslave ; ln -sf /opt/kde/share/doc/HTML/xh/common common )
( cd opt/kde/share/doc/HTML/xh/kaddressbook ; rm -rf common )
( cd opt/kde/share/doc/HTML/xh/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/xh/common common )
( cd opt/kde/share/doc/HTML/xh/kspell ; rm -rf common )
( cd opt/kde/share/doc/HTML/xh/kspell ; ln -sf /opt/kde/share/doc/HTML/xh/common common )
( cd opt/kde/share/doc/HTML/xh/konqueror ; rm -rf common )
( cd opt/kde/share/doc/HTML/xh/konqueror ; ln -sf /opt/kde/share/doc/HTML/xh/common common )
